@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Calendar" : "المفكرة",
     "Hello," : "مرحبا %s،",
+    "Recipient" : "المتلقي",
     "Individual" : "فرد",
     "Group" : "مجموعة",
     "Resource" : "مصدر",
@@ -11,9 +12,12 @@ OC.L10N.register(
     "Required" : "مطلوب",
     "Optional" : "اختياري",
     "Does not attend" : "لا يحضر",
+    "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "المنطقة الزمنية التي أنت فيها ({tz}) غير معروفة ، سيتم الرجوع إلى توقيت UTC",
-    "Please create a calendar first." : "في البدء أنشئ تقويماً من فضلك",
+    "Please create a calendar first." : "أنشئ أولا تقويمًا من فضلك.",
     "New event" : "حدث جديد",
+    "Share Calendar" : "مشاركة المفكرة",
+    "Shared" : "مشارك",
     "group" : "مجموعة",
     "Details" : "تفاصيل",
     "Attendees" : "المشاركون",
@@ -25,6 +29,7 @@ OC.L10N.register(
     "Confirmed" : "مؤكَّد",
     "Tentative" : "مبدئي",
     "Cancelled" : "ملغي",
+    "Please add a title." : "يرجى إضافة عنوان.",
     "Global" : "عالمي",
     "None" : "لا شيء",
     "Every day" : "كل يوم",
@@ -64,6 +69,8 @@ OC.L10N.register(
     "{type} at {time}" : "{type} في {time}",
     "{calendar} shared by {owner}" : "شارك {owner} {calendar}",
     "Title of the Event" : "عنوان الحدث",
+    "Starts" : "يبدأ مِن",
+    "Ends" : "ينتهي في",
     "All day Event" : "حدث طيلة اليوم",
     "Delete" : "حذف ",
     "Cancel" : "إلغاء",
@@ -80,17 +87,20 @@ OC.L10N.register(
     "Week" : "أسبوع",
     "Month" : "شهر",
     "Today" : "اليوم",
-    "Share Calendar" : "مشاركة المفكرة",
-    "Shared" : "مشارك",
     "More" : "المزيد",
     "Edit" : "تعديل",
     "Link" : "الرابط",
     "Download" : "تحميل",
     "Share with users or groups" : "شارِك مع مستخدمين أو مجموعات",
     "can edit" : "يمكن التحرير",
+    "Share link" : "رابط المشاركة",
+    "Public access" : "العنوان العمومي",
+    "Send" : "إرسال",
     "New Calendar" : "مفكرة جديدة",
     "Name" : "الاسم",
     "New Subscription" : "اشتراك جديد",
+    "Go back" : "العودة",
+    "Go forward" : "المواصلة",
     "Edit event" : "تعديل الحدث",
     "Delete Event" : "حذف الحدث",
     "Save Event" : "حفظ الحدث",
@@ -115,7 +125,10 @@ OC.L10N.register(
     "Analyzing calendar" : "تحليل التقويم جارٍ",
     "The file contains objects incompatible with the selected calendar" : "يحوي الملف كائنات غير متوافقة مع التقويم المختار",
     "New calendar" : "مفكرة جديدة",
+    "File is empty" : "الملف فارغ",
     "Import scheduled" : "الاستيراد مُجدوَل",
+    "Publish URL" : "نشر الرابط",
+    "Show week numbers" : "إظهار رقم الأسابيع",
     "Import calendar" : "استيراد التقويم",
     "No Calendars selected for import" : "لم تختر تقويمات للاستيراد",
     "Primary CalDAV address" : "الرئيسية CalDAV عناوين",
