@@ -23,7 +23,9 @@ OC.L10N.register(
     "Please create a calendar first." : "Por favor, crea entantes un calendariu.",
     "New event" : "Eventu nuevu",
     "CalDAV address for clients" : "Direición CalDAV pa veceros",
-    "Error saving WebCal-calendar" : "Fallu guardando'l calendariu WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Dalgunos eventos nesti calendariu tán francíos. Por favor, compruebe la consola JS pa más información.",
+    "Share Calendar" : "Compartir calendariu",
+    "Shared" : "Compartíu",
     "WebDAV address for subscriptions" : "Direición WebDAV pa soscripciones",
     "group" : "grupu",
     "Details" : "Detalles",
@@ -92,9 +94,6 @@ OC.L10N.register(
     "Week" : "Selmana",
     "Month" : "Mes",
     "Today" : "Güei",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Dalgunos eventos nesti calendariu tán francíos. Por favor, compruebe la consola JS pa más información.",
-    "Share Calendar" : "Compartir calendariu",
-    "Shared" : "Compartíu",
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Enllaz",
@@ -137,6 +136,7 @@ OC.L10N.register(
     "Import scheduled" : "Importar horariu",
     "%s shared the calendar <strong>%s</strong> with you" : "%s compartió'l calendariu <strong>%s</strong> contigo",
     "Publish URL" : "Espublizar URL",
+    "Settings & import" : "Axustes ya importación",
     "Skip simple event editor" : "Saltar editor d'eventos simples",
     "Show week numbers" : "Amosar númberos de la selmana",
     "Import calendar" : "Importar calendariu",
