@@ -4,6 +4,7 @@ OC.L10N.register(
     "Calendar" : "Календар",
     "Hello," : "Здравей, ",
     "Cheers!" : "Поздрави!",
+    "Recipient" : "Получател",
     "Too many redirects. Aborting ..." : "Прекалено много пренасочвания. Прекъсване ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Отдалечения сървър не предостави достъп до календара (HTTP {%s} грешка)",
     "Error connecting to remote server" : "Грешка при свързване с отдалечен сървър",
@@ -22,8 +23,12 @@ OC.L10N.register(
     "Please create a calendar first." : "Моля създайте каландар първо.",
     "New event" : "Ново събитие",
     "CalDAV address for clients" : "CalDAV адрес за клиенти",
-    "Error saving WebCal-calendar" : "Грешка при запаметяване на WebCal-календар",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Някои събития в този календар са счупени. Моля погледни JS конзолата за подробности.",
+    "Share Calendar" : "Споделяне на Календара",
+    "Shared" : "Споделено",
     "WebDAV address for subscriptions" : "WebDAV адрес за абонаменти",
+    "Email sent." : "Е-Мейла е изпратен.",
+    "Could not send your email." : "Не мога да изпратя вашия Е-Мейл.",
     "group" : "група",
     "Details" : "Детайли",
     "Attendees" : "Присъстващи",
@@ -35,6 +40,9 @@ OC.L10N.register(
     "Confirmed" : "Потвърдено",
     "Tentative" : "Несигурно",
     "Cancelled" : "Отказано",
+    "Please add a title." : "Моля добавете заглавие.",
+    "Please select a calendar." : "Моля изберете календар.",
+    "The event can not end before it starts." : "Събитието не може да приключи, преди да започне.",
     "Global" : "Глобално",
     "None" : "Няма",
     "Every day" : "Всеки ден",
@@ -53,6 +61,7 @@ OC.L10N.register(
     "2 hours before" : "2 часа преди ",
     "Custom" : "Избирателно",
     "Audio" : "Аудио",
+    "Email" : "Е-Мейл",
     "Pop-up" : "Изкачащ прозорец",
     "sec" : "секунда",
     "min" : "минимално",
@@ -64,6 +73,7 @@ OC.L10N.register(
     "end" : "край",
     "Editing reminders of unknown type not supported." : "Редактиране на напомняния от непознат тип не се поддържа",
     "Week {number} of {year}" : "Седмица {number} от {year}",
+    "Successfully imported {imported} objects" : "Успешно бяха импортирани {imported} обекта",
     "{type} {time} before the event starts" : "{type} {time} преди началото на събитието",
     "{type} {time} before the event ends" : "{type} {time} преди края на събитието",
     "{type} {time} after the event starts" : "{type} {time} след началото на събитието",
@@ -98,9 +108,6 @@ OC.L10N.register(
     "Week" : "Седмица",
     "Month" : "Месец",
     "Today" : "Днес",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Някои събития в този календар са счупени. Моля погледни JS конзолата за подробности.",
-    "Share Calendar" : "Споделяне на Календара",
-    "Shared" : "Споделено",
     "More" : "Още",
     "Edit" : "Редакция",
     "Link" : "Връзка",
@@ -129,6 +136,7 @@ OC.L10N.register(
     "Repeat" : "Да се повтаря",
     "times every" : "на всеки",
     "Add" : "Добави",
+    "Email address of attendee" : "Е-Мейл адрес на участник",
     "Please add your email address in the personal settings in order to add attendees." : "Добави e-mail адреса си в личните настройки за да можеш да добавяш участници.",
     "from" : "от",
     "to" : "до",
