@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Si us plau, creeu un calendari primer",
     "New event" : "Esdeveniment nou",
     "CalDAV address for clients" : "Adreça CalDAV per els clients",
-    "Error saving WebCal-calendar" : "Error desant el calendari WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns esdeveniments d'aquest calendari contenen errors. Revisa la consola JS per a més informació.",
+    "Share Calendar" : "Comparteix el calendari",
+    "Shared" : "Compartit",
     "WebDAV address for subscriptions" : "Adreça WebDAV per subscripcions",
-    "Email has been sent." : "S'ha enviat el correu.",
-    "There was an issue while sending your email." : "S'ha produït un problema al enviar el teu correu electrònic.",
     "group" : "grup",
     "Details" : "Detalls",
     "Attendees" : "Assistents",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Setmana",
     "Month" : "Mes",
     "Today" : "Avui",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns esdeveniments d'aquest calendari contenen errors. Revisa la consola JS per a més informació.",
-    "Share Calendar" : "Comparteix el calendari",
-    "Shared" : "Compartit",
     "More" : "Més",
     "Edit" : "Edita",
     "Link" : "Enllaç",
