@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Nejdříve prosím vytvořte kalendář.",
     "New event" : "Nová událost",
     "CalDAV address for clients" : "CalDAV adresa pro klientské aplikace",
-    "Error saving WebCal-calendar" : "Chyba při ukládání WebCal kalendáře",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "V tomto kalendáři jsou některé události poškozené. Pro více informací prosím nahlédněte do JS konzole.",
+    "Share Calendar" : "Sdílet kalendář",
+    "Shared" : "Sdílené",
     "WebDAV address for subscriptions" : "WebDAV adresa pro odběry",
-    "Email has been sent." : "Email byl odeslán.",
-    "There was an issue while sending your email." : "Došlo k problému v průběhu odesílání emailu.",
     "group" : "skupina",
     "Details" : "Podrobnosti",
     "Attendees" : "Účastníci",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Týden",
     "Month" : "Měsíc",
     "Today" : "Dnes",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "V tomto kalendáři jsou některé události poškozené. Pro více informací prosím nahlédněte do JS konzole.",
-    "Share Calendar" : "Sdílet kalendář",
-    "Shared" : "Sdílené",
     "More" : "Více",
     "Edit" : "Upravit",
     "Link" : "Odkaz",
