@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Opret venligst en kalender først",
     "New event" : "Opret begivenhed",
     "CalDAV address for clients" : "CalDAV addresse for klienter",
-    "Error saving WebCal-calendar" : "Kunne ikke gemme WebCal-kalender",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
+    "Share Calendar" : "Del kalender",
+    "Shared" : "Delt",
     "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
-    "Email has been sent." : "E-mailen er sendt.",
-    "There was an issue while sending your email." : "Der opstod en fejl i forsøget på at sende din e-mail",
     "group" : "gruppe",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Uge",
     "Month" : "Måned",
     "Today" : "I dag",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
-    "Share Calendar" : "Del kalender",
-    "Shared" : "Delt",
     "More" : "Mere",
     "Edit" : "Redigér",
     "Link" : "Link",
