@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
     "New event" : "Neuer Ereignis",
     "CalDAV address for clients" : "CalDAV-Adresse für Clients",
-    "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfen Sie die JavaScript-Konsole für weitere Informationen.",
+    "Share Calendar" : "Kalender teilen",
+    "Shared" : "Geteilt",
+    "Could not save WebCal-calendar" : "Der WebCal-Kalender konnte nicht gespeichert werden",
     "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
-    "Email has been sent." : "E-Mail versandt",
-    "There was an issue while sending your email." : "Beim Versand der E-Mail ist ein Fehler aufgetreten",
+    "Email sent." : "E-Mail gesendet.",
+    "Could not send your email." : "E-Mail konnte nicht versandt werden.",
     "group" : "Gruppe",
     "Details" : "Details",
     "Attendees" : "Teilnehmer",
@@ -142,9 +145,6 @@ OC.L10N.register(
     "Week" : "Woche",
     "Month" : "Monat",
     "Today" : "Heute",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfen Sie die JavaScript-Konsole für weitere Informationen.",
-    "Share Calendar" : "Kalender teilen",
-    "Shared" : "Geteilt",
     "More" : "Mehr",
     "Edit" : "Bearbeiten",
     "Link" : "Link",
@@ -172,7 +172,7 @@ OC.L10N.register(
     "Absolute" : "Absolut",
     "Repeat" : "Wiederholen",
     "times every" : "mal pro",
-    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "E-Mail-Erinnerungen wurden bisher noch nicht im CalDAV-Server umgesetzt. Daher werden aktuell keine E-Mail-Erinnerungen gesendet.",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-Mail-Erinnerungen wurden bisher nicht im CalDAV-Server umgesetzt, daher werden keine versendet.",
     "Add" : "Hinzufügen",
     "Email address of attendee" : "E-Mail-Adresse des Teilnehmers",
     "Please add your email address in the personal settings in order to add attendees." : "Bitte fügen Sie ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
