@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Παρακαλώ πρώτα δημιουργήστε ένα ημερολόγιο",
     "New event" : "Νέο συμβάν",
     "CalDAV address for clients" : "Διεύθυνση CalDAV για πελάτες",
-    "Error saving WebCal-calendar" : "Σφαλμα αποθήκευσης WebCal-calendar ",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Μερικά συμβάντα σε αυτό το ημερολόγιο δεν λειτουργούν. Παρακαλούμε ελέγξτε την κονσόλα JS για περισσότερες πληροφορίες.",
+    "Share Calendar" : "Διαμοιράστε ένα ημερολόγιο",
+    "Shared" : "Κοινόχρηστα",
     "WebDAV address for subscriptions" : "WebDAV διευθύνσεις για συνδρομές",
-    "Email has been sent." : "Το Email απεστάλη.",
-    "There was an issue while sending your email." : "Υπήρξε πρόβλημα κατά την αποστολή του email. ",
     "group" : "ομάδα",
     "Details" : "Λεπτομέρειες",
     "Attendees" : "Συμμετέχοντες",
@@ -74,10 +74,14 @@ OC.L10N.register(
     "end" : "τέλος",
     "Editing reminders of unknown type not supported." : "Δεν υποστηρίζεται η επεξεργασία υπενθυμίσεων άγνωστου τύπου.",
     "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
+    "Successfully imported {imported} objects" : "Επιτυχής εισαγωγή {imported} αντικειμένων",
+    "Audio alarm {time} before the event starts" : "Ηχητική ειδοποίηση {time} πριν την έναρξη του συμβάντος",
+    "Email {time} before the event starts" : "Αποστολή email {time} πριν την έναρξη του συμβάντος.",
     "{type} {time} before the event starts" : "{type} {time} πριν την έναρξη του συμβάντος",
     "{type} {time} before the event ends" : "{type} {time} πριν τη λήξη του συμβάντος",
     "{type} {time} after the event starts" : "{type} {time} μετά την έναρξη του συμβάντος",
     "{type} {time} after the event ends" : "{type} {time} μετά τη λήξη του συμβάντος",
+    "Pop-up at the event's start" : "Αναδυόμενη ειδοποίηση κατά την έναρξη του συμβάντος",
     "{type} at the event's start" : "{type} στην έναρξη του γεγονότος",
     "{type} at the event's end" : "{type} στο τέλος του γεγονότος",
     "{type} at {time}" : "{type} στις {time}",
@@ -108,9 +112,6 @@ OC.L10N.register(
     "Week" : "Εβδομάδα",
     "Month" : "Μήνας",
     "Today" : "Σήμερα",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Μερικά συμβάντα σε αυτό το ημερολόγιο δεν λειτουργούν. Παρακαλούμε ελέγξτε την κονσόλα JS για περισσότερες πληροφορίες.",
-    "Share Calendar" : "Διαμοιράστε ένα ημερολόγιο",
-    "Shared" : "Κοινόχρηστα",
     "More" : "Περισσότερα",
     "Edit" : "Επεξεργασία",
     "Link" : "Σύνδεσμος",
@@ -138,6 +139,7 @@ OC.L10N.register(
     "Absolute" : "Απόλυτο",
     "Repeat" : "Επανάληψη",
     "times every" : "φορές κάθε",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Οι ειδοποιήσεις μέσω email δεν έχουν ενεργοποιηθεί ακόμα στον διακομιστή CalDAV, οπότε δεν θα σταλεί καμία.",
     "Add" : "Προσθήκη",
     "Email address of attendee" : "Διεύθυνση ηλεκτρονικής αλληλογραφίας συμμετέχοντος",
     "Please add your email address in the personal settings in order to add attendees." : "Παρακαλώ προσθέστε τη διεύθυνση ηλεκτρονικής αλληλογραφίας σας στις προσωπικές ρυθμίσεις για να προσθέσετε συμμετέχοντες.",
