@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Please create a calendar first.",
     "New event" : "New event",
     "CalDAV address for clients" : "CalDAV address for clients",
-    "Error saving WebCal-calendar" : "Error saving WebCal-calendar",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Some events in this calendar are broken. Please check the JS console for more info.",
+    "Share Calendar" : "Share Calendar",
+    "Shared" : "Shared",
     "WebDAV address for subscriptions" : "WebDAV address for subscription",
-    "Email has been sent." : "Email has been sent.",
-    "There was an issue while sending your email." : "There was an issue while sending your email.",
     "group" : "group",
     "Details" : "Details",
     "Attendees" : "Attendees",
@@ -74,12 +74,46 @@ OC.L10N.register(
     "end" : "end",
     "Editing reminders of unknown type not supported." : "Editing reminders of unknown type not supported.",
     "Week {number} of {year}" : "Week {number} of {year}",
+    "Successfully imported {imported} objects" : "Successfully imported {imported} objects",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Imported {imported} out of {all}, skipped one duplicate",
+    "Imported {imported} out of {all}, one failure" : "Imported {imported} out of {all}, one failure",
+    "Imported {imported} out of {all}, {errors} failures" : "Imported {imported} out of {all}, {errors} failures",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Imported {imported} out of {all}, skipped {duplicates} duplicates",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates",
+    "Audio alarm {time} before the event starts" : "Audio alarm {time} before the event starts",
+    "Pop-up {time} before the event starts" : "Pop-up {time} before the event starts",
+    "Email {time} before the event starts" : "Email {time} before the event starts",
+    "None {time} before the event starts" : "None {time} before the event starts",
     "{type} {time} before the event starts" : "{type} {time} before the event starts",
+    "Audio alarm {time} before the event ends" : "Audio alarm {time} before the event ends",
+    "Pop-up {time} before the event ends" : "Pop-up {time} before the event ends",
+    "Email {time} before the event ends" : "Email {time} before the event ends",
+    "None {time} before the event ends" : "None {time} before the event ends",
     "{type} {time} before the event ends" : "{type} {time} before the event ends",
+    "Audio alarm {time} after the event starts" : "Audio alarm {time} after the event starts",
+    "Pop-up {time} after the event starts" : "Pop-up {time} after the event starts",
+    "Email {time} after the event starts" : "Email {time} after the event starts",
+    "None {time} after the event starts" : "None {time} after the event starts",
     "{type} {time} after the event starts" : "{type} {time} after the event starts",
+    "Audio alarm {time} after the event ends" : "Audio alarm {time} after the event ends",
+    "Pop-up {time} after the event ends" : "Pop-up {time} after the event ends",
+    "Email {time} after the event ends" : "Email {time} after the event ends",
+    "None {time} after the event ends" : "None {time} after the event ends",
     "{type} {time} after the event ends" : "{type} {time} after the event ends",
+    "Audio alarm at the event's start" : "Audio alarm at the event's start",
+    "Pop-up at the event's start" : "Pop-up at the event's start",
+    "Email at the event's start" : "Email at the event's start",
+    "None at the event's start" : "None at the event's start",
     "{type} at the event's start" : "{type} at the event's start",
+    "Audio alarm at the event's end" : "Audio alarm at the event's end",
+    "Pop-up at the event's end" : "Pop-up at the event's end",
+    "Email at the event's end" : "Email at the event's end",
+    "None at the event's end" : "None at the event's end",
     "{type} at the event's end" : "{type} at the event's end",
+    "Audio alarm at {time}" : "Audio alarm at {time}",
+    "Pop-up at {time}" : "Pop-up at {time}",
+    "Email at {time}" : "Email at {time}",
+    "None at {time}" : "None at {time}",
     "{type} at {time}" : "{type} at {time}",
     "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
     "Please enter a valid WebCal-URL" : "Please enter a valid WebCal-URL",
@@ -108,9 +142,6 @@ OC.L10N.register(
     "Week" : "Week",
     "Month" : "Month",
     "Today" : "Today",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Some events in this calendar are broken. Please check the JS console for more info.",
-    "Share Calendar" : "Share Calendar",
-    "Shared" : "Shared",
     "More" : "More",
     "Edit" : "Edit",
     "Link" : "Link",
@@ -138,6 +169,7 @@ OC.L10N.register(
     "Absolute" : "Absolute",
     "Repeat" : "Repeat",
     "times every" : "times every",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Email reminders have not been implemented in the CalDAV server yet, so none will be sent.",
     "Add" : "Add",
     "Email address of attendee" : "Email address of attendee",
     "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
