@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Por favor, cree primero un calendario.",
     "New event" : "Nuevo evento",
     "CalDAV address for clients" : "Dirección CalDAV para los clientes",
-    "Error saving WebCal-calendar" : "Error salvando Calendario-WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
+    "Share Calendar" : "Compartir calendario",
+    "Shared" : "Compartido",
     "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
-    "Email has been sent." : "Se ha enviado un correo electrónico.",
-    "There was an issue while sending your email." : "Hubo un problema al enviar tu correo.",
     "group" : "grupo",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
@@ -74,12 +74,46 @@ OC.L10N.register(
     "end" : "fin",
     "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
     "Week {number} of {year}" : "Semana {number} de {year}",
+    "Successfully imported {imported} objects" : "Se han importado con éxito {imported} objetos",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Se han importado {imported} de un total de {all}, se ha omitido un duplicado",
+    "Imported {imported} out of {all}, one failure" : "Se han importado {imported} de un total de {all}, un fallo",
+    "Imported {imported} out of {all}, {errors} failures" : "Se han importado {imported} de un total de {all}, {errors} fallos",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Se han importado {imported} de un un total de {all}, se han omitido {duplicates} duplicados",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Se han importado {imported} de un total de {all}, {errors} fallos, se han omitido {duplicates} duplicados",
+    "Audio alarm {time} before the event starts" : "Alarma sonora {time} antes de que comience el evento",
+    "Pop-up {time} before the event starts" : "Ventana de aviso {time} antes de que comience el evento",
+    "Email {time} before the event starts" : "Correo electrónico {time} antes de que comience el evento",
+    "None {time} before the event starts" : "Nada {time} antes de que comience el evento",
     "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
+    "Audio alarm {time} before the event ends" : "Alarma sonora {time} antes de que termine el evento",
+    "Pop-up {time} before the event ends" : "Ventana de aviso {time} antes de que termine el evento",
+    "Email {time} before the event ends" : "Correo electrónico {time} antes de que termine el evento",
+    "None {time} before the event ends" : "Nada {time} antes de que termine el evento",
     "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
+    "Audio alarm {time} after the event starts" : "Alarma sonora {time} después de que comience el evento",
+    "Pop-up {time} after the event starts" : "Ventana de aviso {time} después de que comience el evento",
+    "Email {time} after the event starts" : "Correo electrónico {time} después de que comience el evento",
+    "None {time} after the event starts" : "Nada {} después de que comience el evento",
     "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
+    "Audio alarm {time} after the event ends" : "Alarma sonora {time} después de que termine el evento",
+    "Pop-up {time} after the event ends" : "Ventana de aviso {time} después de que termine el evento",
+    "Email {time} after the event ends" : "Correo electrónico {time} después de que termine el evento",
+    "None {time} after the event ends" : "Nada {time} después de que termine el evento",
     "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
+    "Audio alarm at the event's start" : "Alarma sonora al comienzo del evento",
+    "Pop-up at the event's start" : "Ventana de aviso al comienzo del evento",
+    "Email at the event's start" : "Correo electrónico al comienzo del evento",
+    "None at the event's start" : "Nada al comienzo del evento",
     "{type} at the event's start" : "{type} al inicio del evento",
+    "Audio alarm at the event's end" : "Alarma sonora al final del evento",
+    "Pop-up at the event's end" : "Ventana de aviso al final del evento",
+    "Email at the event's end" : "Correo electrónico al final del evento",
+    "None at the event's end" : "Nada al final del evento",
     "{type} at the event's end" : "{type} al final del evento",
+    "Audio alarm at {time}" : "Alarma sonora a las {time}",
+    "Pop-up at {time}" : "Ventana de aviso a las {time}",
+    "Email at {time}" : "Correo electrónico a las {time}",
+    "None at {time}" : "Nada a las {time}",
     "{type} at {time}" : "{type} a {time}",
     "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
     "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
@@ -108,9 +142,6 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mes",
     "Today" : "Hoy",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
-    "Share Calendar" : "Compartir calendario",
-    "Shared" : "Compartido",
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Enlace",
@@ -138,6 +169,7 @@ OC.L10N.register(
     "Absolute" : "Absoluto",
     "Repeat" : "Repetir",
     "times every" : "veces cada",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Los recordatorios de correo todavía no se han implementado en el servidor, por lo que no se enviarán.",
     "Add" : "Añadir",
     "Email address of attendee" : "Correo electrónico del asistente",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su correo electrónico en la configuración de su cuenta para agregar asistentes",
