@@ -22,10 +22,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Favor de crear un calendario primero.",
     "New event" : "Nuevo evento",
     "CalDAV address for clients" : "Dirección CalDAV para clientes",
-    "Error saving WebCal-calendar" : "Error al guardar el calendaro WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos en este calenario están rotos. Favor de verificar la consola JS para más información. ",
+    "Share Calendar" : "Compartir calendario",
+    "Shared" : "Compartido",
     "WebDAV address for subscriptions" : "Dirección WebDav para suscripciones",
-    "Email has been sent." : "El correo electrónico ha sido enviado. ",
-    "There was an issue while sending your email." : "Se presentó un tema al enviar su correo electrónico. ",
     "group" : "grupo",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
@@ -104,9 +104,6 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mes",
     "Today" : "Hoy",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos en este calenario están rotos. Favor de verificar la consola JS para más información. ",
-    "Share Calendar" : "Compartir calendario",
-    "Shared" : "Compartido",
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Link",
