@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Luo ensin kalenteri.",
     "New event" : "Uusi tapahtuma",
     "CalDAV address for clients" : "CalDAV-osoite asiakasohjelmille",
-    "Error saving WebCal-calendar" : "Virhe tallentaessa WebCal-kalenteria",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
+    "Share Calendar" : "Jaa kalenteri",
+    "Shared" : "Jaettu",
     "WebDAV address for subscriptions" : "WebDAV-osoite tilauksille",
-    "Email has been sent." : "Sähköposti on lähetetty",
-    "There was an issue while sending your email." : "Virhe lähetettäessä sähköpostia.",
     "group" : "ryhmä",
     "Details" : "Tiedot",
     "Attendees" : "Osallistujat",
@@ -74,12 +74,46 @@ OC.L10N.register(
     "end" : "loppu",
     "Editing reminders of unknown type not supported." : "Tuntemattoman tyyppisten muistutusten muokkaamista ei tueta.",
     "Week {number} of {year}" : "Viikko {number} vuonna {year}",
+    "Successfully imported {imported} objects" : "Tuotiin onnistuneesti {imported} objektia",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Tuotiin {imported}/{all}, ohitettiin yksi kaksoiskappale",
+    "Imported {imported} out of {all}, one failure" : "Tuotiin {imported}/{all}, yksi epäonnistuminen",
+    "Imported {imported} out of {all}, {errors} failures" : "Tuotiin {imported}/{all}, {errors} epäonnistumista",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Tuotiin {imported}/{all}, ohitettiin {duplicates} kaksoiskappaletta",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Tuotiin {imported}/{all}, {errors} epäonnistumista, ohitettiin {duplicates} kaksoiskappaletta",
+    "Audio alarm {time} before the event starts" : "Äänihälytys {time} ennen tapahtuman alkua",
+    "Pop-up {time} before the event starts" : "Ponnahdus {time} ennen tapahtuman alkua",
+    "Email {time} before the event starts" : "Sähköposti {time} ennen tapahtuman alkua",
+    "None {time} before the event starts" : "Ei mitään {time} ennen tapahtuman alkua",
     "{type} {time} before the event starts" : "{type} {time} ennen tapahtuman alkua",
+    "Audio alarm {time} before the event ends" : "Äänihälytys {time} ennen tapahtuman loppua",
+    "Pop-up {time} before the event ends" : "Ponnahdus {time} ennen tapahtuman loppua",
+    "Email {time} before the event ends" : "Sähköposti {time} ennen tapahtuman loppua",
+    "None {time} before the event ends" : "Ei mitään {time} ennen tapahtuman loppua",
     "{type} {time} before the event ends" : "{type} {time} ennen tapahtuman loppua",
+    "Audio alarm {time} after the event starts" : "Äänihälytys {time} tapahtuman alkamisen jälkeen",
+    "Pop-up {time} after the event starts" : "Ponnahdus {time} tapahtuman alkamisen jälkeen",
+    "Email {time} after the event starts" : "Sähköposti {time} tapahtuman alkamisen jälkeen",
+    "None {time} after the event starts" : "Ei mitään {time} tapahtuman alkamisen jälkeen",
     "{type} {time} after the event starts" : "{type} {time} tapahtuman alkamisen jälkeen",
+    "Audio alarm {time} after the event ends" : "Äänihälytys {time} tapahtuman päättymisen jälkeen",
+    "Pop-up {time} after the event ends" : "Ponnahdus {time} tapahtuman päättymisen jälkeen",
+    "Email {time} after the event ends" : "Sähköposti {time} tapahtuman päättymisen jälkeen",
+    "None {time} after the event ends" : "Ei mitään {time} tapahtuman päättymisen jälkeen",
     "{type} {time} after the event ends" : "{type} {time} tapahtuman päättymisen jälkeen",
+    "Audio alarm at the event's start" : "Äänihälytys tapahtuman alkaessa",
+    "Pop-up at the event's start" : "Ponnahdus tapahtuman alkaessa",
+    "Email at the event's start" : "Sähköposti tapahtuman alkaessa",
+    "None at the event's start" : "Ei mitään tapahtuman alkaessa",
     "{type} at the event's start" : "{type} tapahtuman alkaessa",
+    "Audio alarm at the event's end" : "Äänihälytys tapahtuman päättyessä",
+    "Pop-up at the event's end" : "Ponnahdus tapahtuman päättyessä",
+    "Email at the event's end" : "Sähköposti tapahtuman päättyessä",
+    "None at the event's end" : "Ei mitään tapahtuman päättyessä",
     "{type} at the event's end" : "{type} tapahtuman päättyessä",
+    "Audio alarm at {time}" : "Äänihälytys {time}",
+    "Pop-up at {time}" : "Ponnahdus {time}",
+    "Email at {time}" : "Sähköposti {time}",
+    "None at {time}" : "Ei mitään {time}",
     "{type} at {time}" : "{type} ajankohtana {time}",
     "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
     "Please enter a valid WebCal-URL" : "Anna kelvollinen WebCal-osoite",
@@ -108,9 +142,6 @@ OC.L10N.register(
     "Week" : "Viikko",
     "Month" : "Kuukausi",
     "Today" : "Tänään",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
-    "Share Calendar" : "Jaa kalenteri",
-    "Shared" : "Jaettu",
     "More" : "Lisää",
     "Edit" : "Muokkaa",
     "Link" : "Linkki",
@@ -138,6 +169,7 @@ OC.L10N.register(
     "Absolute" : "Absoluuttinen",
     "Repeat" : "Kertaa",
     "times every" : "kertaa joka",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Sähköpostimuistutuksia ei ole vielä toteutettu CalDAV-palvelimelle, joten mitään sähköpostiviestejä ei lähetetä.",
     "Add" : "Lisää",
     "Email address of attendee" : "Osallistujan sähköpostiosoite",
     "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
