@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "Először naptárat készítsen",
     "New event" : "Új esemény",
     "CalDAV address for clients" : "CalDAV cím a klienseknek",
-    "Error saving WebCal-calendar" : "WebCal naptár mentési hiba",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Néhány esemény hibás ebben a naptárban. További információkért kérek ellenőrizd a JS konzolt.",
+    "Share Calendar" : "A naptár megosztása",
+    "Shared" : "Megosztott",
+    "Could not save WebCal-calendar" : "Nem sikerült menteni a WebCal-naptárat",
     "WebDAV address for subscriptions" : "WebDAV cím a feliratkozásokhoz",
-    "Email has been sent." : "E-mail elküldve.",
-    "There was an issue while sending your email." : "Probléma lépett fel az e-mail elküldése során.",
+    "Email sent." : "Az e-mail elküldve.",
+    "Could not send your email." : "Az e-mail küldése sikertelen.",
     "group" : "csoport",
     "Details" : "Részletek",
     "Attendees" : "Résztvevők",
@@ -74,12 +77,46 @@ OC.L10N.register(
     "end" : "vég",
     "Editing reminders of unknown type not supported." : "Ismeretlen típusú emlékeztetős szerkesztése nem támogatott.",
     "Week {number} of {year}" : "{year} év {number}. hete",
+    "Successfully imported {imported} objects" : "{imported} objektum sikeresen importálva",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{imported}/{all} importálva, egy duplikátum kihagyva",
+    "Imported {imported} out of {all}, one failure" : "{imported}/{all} importálva, egy hiba",
+    "Imported {imported} out of {all}, {errors} failures" : "{imported}/{all} importálva, {errors} hiba",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported}/{all} importálva, {duplicates} duplikátum kihagyva",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported}/{all} importálva, {errors} hiba, {duplicates} duplikátum kihagyva",
+    "Audio alarm {time} before the event starts" : "Hangriasztás az esemény kezdete előtt ennyivel: {time}",
+    "Pop-up {time} before the event starts" : "Felugró üzenet az esemény kezdete előtt ennyivel: {time}",
+    "Email {time} before the event starts" : "Email az esemény kezdete előtt ennyivel: {time}",
+    "None {time} before the event starts" : "Nincs {time} idővel az esemény kezdete előtt",
     "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
+    "Audio alarm {time} before the event ends" : "Hangriasztás az esemény vége előtt ennyivel: {time}",
+    "Pop-up {time} before the event ends" : "Felugró üzenet az esemény vége előtt ennyivel: {time}",
+    "Email {time} before the event ends" : "Email az esemény vége előtt ennyivel: {time}",
+    "None {time} before the event ends" : "Nincs {time} idővel az esemény vége előtt",
     "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
+    "Audio alarm {time} after the event starts" : "Hangriasztás az esemény kezdete után ennyivel: {time}",
+    "Pop-up {time} after the event starts" : "Felugró üzenet az esemény kezdete után ennyivel: {time}",
+    "Email {time} after the event starts" : "Email az esemény kezdete után ennyivel: {time}",
+    "None {time} after the event starts" : "Nincs {time} idővel az esemény kezdése után",
     "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
+    "Audio alarm {time} after the event ends" : "Hangriasztás az esemény vége után ennyivel: {time}",
+    "Pop-up {time} after the event ends" : "Felugró üzenet az esemény vége után ennyivel: {time}",
+    "Email {time} after the event ends" : "Email az esemény vége után ennyivel: {time}",
+    "None {time} after the event ends" : "Nincs {time} idővel az esemény után",
     "{type} {time} after the event ends" : "{type} {time} esemény vége után",
+    "Audio alarm at the event's start" : "Hangriasztás az esemény kezdetekor",
+    "Pop-up at the event's start" : "Felugró üzenet az esemény kezdetekor",
+    "Email at the event's start" : "Email az esemény kezdetekor",
+    "None at the event's start" : "Nincs az esemény kezdetén",
     "{type} at the event's start" : "{type} az esemény kezdetekor",
+    "Audio alarm at the event's end" : "Hangriasztás az esemény végén",
+    "Pop-up at the event's end" : "Felugró üzenet az esemény végén",
+    "Email at the event's end" : "Email az esemény végén",
+    "None at the event's end" : "Nincs az esemény végén",
     "{type} at the event's end" : "{type} az esemény végén",
+    "Audio alarm at {time}" : "Hangriasztás ekkor: {time}",
+    "Pop-up at {time}" : "Felugró üzenet ekkor: {time}",
+    "Email at {time}" : "Email ekkor: {time}",
+    "None at {time}" : "Semmi ekkor {time}",
     "{type} at {time}" : "{type} ekkor: {time}",
     "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
     "Please enter a valid WebCal-URL" : "Kérlek adj meg egy érvényes WebCal-URL-t",
@@ -108,9 +145,6 @@ OC.L10N.register(
     "Week" : "Hét",
     "Month" : "Hónap",
     "Today" : "Ma",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Néhány esemény hibás ebben a naptárban. További információkért kérek ellenőrizd a JS konzolt.",
-    "Share Calendar" : "A naptár megosztása",
-    "Shared" : "Megosztott",
     "More" : "Több",
     "Edit" : "Szerkesztés",
     "Link" : "Hivatkozás",
@@ -138,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Abszolút",
     "Repeat" : "Ismétlés",
     "times every" : "mindennyiszer",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Az email emlékeztetők még nincsenek implementálva a CalDAV szerverbe, ezért semmi nem lesz elküldve.",
     "Add" : "Hozzáadás",
     "Email address of attendee" : "Résztvevők e-mail címe",
     "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az email címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
