@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Búðu fyrst til dagatal.",
     "New event" : "Nýr atburður",
     "CalDAV address for clients" : "CalDAV-vistfang fyrir biðlara",
-    "Error saving WebCal-calendar" : "Villa við að vista WebCal-dagatal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
+    "Share Calendar" : "Deila dagatali",
+    "Shared" : "Deilt",
     "WebDAV address for subscriptions" : "WebDAV-vistfang fyrir áskriftir",
-    "Email has been sent." : "Tölvupósturinn var sendur.",
-    "There was an issue while sending your email." : "Það kom upp vandamál við að senda tölvupóstinn þinn.",
     "group" : "hópur",
     "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Vika",
     "Month" : "Mánuður",
     "Today" : "Í dag",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
-    "Share Calendar" : "Deila dagatali",
-    "Shared" : "Deilt",
     "More" : "Meira",
     "Edit" : "Breyta",
     "Link" : "Tengill",
