@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "Crea prima un calendario.",
     "New event" : "Nuovo evento",
     "CalDAV address for clients" : "Indirizzo CalDAV per i client",
-    "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
+    "Share Calendar" : "Condividi calendario",
+    "Shared" : "Condiviso",
+    "Could not save WebCal-calendar" : "Impossibile salvare il calendario WebCal",
     "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
-    "Email has been sent." : "Il messaggio è stata inviato.",
-    "There was an issue while sending your email." : "Si è verificato un problema durante l'invio del tuo messaggio.",
+    "Email sent." : "Email inviata.",
+    "Could not send your email." : "Impossibile inviare la tua email.",
     "group" : "gruppo",
     "Details" : "Dettagli",
     "Attendees" : "Partecipanti",
@@ -80,9 +83,25 @@ OC.L10N.register(
     "Imported {imported} out of {all}, {errors} failures" : "{imported} importati di {all}, {errors} non riusciti",
     "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} importati di {all}, saltati {duplicates} duplicati",
     "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} importati di {all}, {errors} non riusciti, saltati {duplicates} duplicati",
+    "Audio alarm {time} before the event starts" : "Avviso sonoro {time} prima dell'inizio dell'evento",
+    "Pop-up {time} before the event starts" : "Finestra a comparsa {time} prima dell'inizio dell'evento",
+    "Email {time} before the event starts" : "Email {time} prima dell'inizio dell'evento",
+    "None {time} before the event starts" : "Nessun {time} prima dell'inizio dell'evento",
     "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
+    "Audio alarm {time} before the event ends" : "Avviso sonoro {time} prima della fine dell'evento",
+    "Pop-up {time} before the event ends" : "Finestra a comparsa {time} prima della fine dell'evento",
+    "Email {time} before the event ends" : "Email {time} prima della fine dell'evento",
+    "None {time} before the event ends" : "Nessun {time} prima della fine dell'evento",
     "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
+    "Audio alarm {time} after the event starts" : "Avviso sonoro {time} dopo l'inizio dell'evento",
+    "Pop-up {time} after the event starts" : "Finestra a comparsa {time} dopo l'inizio dell'evento",
+    "Email {time} after the event starts" : "Email {time} dopo l'inizio dell'evento",
+    "None {time} after the event starts" : "Nessun {time} dopo l'inizio dell'evento",
     "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
+    "Audio alarm {time} after the event ends" : "Avviso sonoro {time} dopo la fine dell'evento",
+    "Pop-up {time} after the event ends" : "Finestra a comparsa {time} dopo la fine dell'evento",
+    "Email {time} after the event ends" : "Email {time} dopo la fine dell'evento",
+    "None {time} after the event ends" : "Nessun {time} dopo la fine dell'evento",
     "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
     "Audio alarm at the event's start" : "Avviso sonoro quando inizia l'evento",
     "Pop-up at the event's start" : "Finestra a comparsa quando inizia l'evento",
@@ -126,9 +145,6 @@ OC.L10N.register(
     "Week" : "Settimana",
     "Month" : "Mese",
     "Today" : "Oggi",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
-    "Share Calendar" : "Condividi calendario",
-    "Shared" : "Condiviso",
     "More" : "Altro",
     "Edit" : "Modifica",
     "Link" : "Collegamento",
@@ -156,7 +172,7 @@ OC.L10N.register(
     "Absolute" : "Assoluto",
     "Repeat" : "Ripeti",
     "times every" : "volte ogni",
-    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "I promemoria via email non sono ancora stati implementati nel server CalDAV, per cui non sarà inviato alcuna promemoria tramite posta.",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "I promemoria via email non sono ancora stati implementati nel server CalDAV, per cui non sarà inviato niente.",
     "Add" : "Aggiungi",
     "Email address of attendee" : "Indirizzo email del partecipante",
     "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
