@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "გთხოვთ ჯერ შექმნათ კალენდარი.",
     "New event" : "ახალი მოვლენა",
     "CalDAV address for clients" : "CalDAV მისამართ კლიენტისთვის",
-    "Error saving WebCal-calendar" : "WebCal კალენდრის შენახვისას წარმოიშვა შეცდომა",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "გარკვეული მოვლენები კალენდარში გაფუჭებულია. დამატებითი ინფორმაციისთვის გთხოვთ იხილოთ JS კონსოლი.",
+    "Share Calendar" : "კალენდარის გაზიარება",
+    "Shared" : "გაზიარებული",
+    "Could not save WebCal-calendar" : "WebCal-კალენდრის შენახვა ვერ მოხერხდა",
     "WebDAV address for subscriptions" : "WebDAV მისამართი გამოწერებისთვის",
-    "Email has been sent." : "ელ-წერილი გაიგზავნა.",
-    "There was an issue while sending your email." : "წერილის გაგზავნასთან დაკავშირებით წარმოიქმნა შეცდომა.",
+    "Email sent." : "ელ-წერილი გაიგზავნა.",
+    "Could not send your email." : "თქვენი ელ-წერილის გაგზავნა ვერ მოხერხდა.",
     "group" : "ჯგუფი",
     "Details" : "დეტლაები",
     "Attendees" : "დამსწრეები",
@@ -74,12 +77,46 @@ OC.L10N.register(
     "end" : "დასასრული",
     "Editing reminders of unknown type not supported." : "ამოუცნობი სახეობის შემახსენებლების შეცვლის მხარდაჭერა არაა.",
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
+    "Successfully imported {imported} objects" : "წარმატებით დაიმპორტდა {imported} ობიექტი",
+    "Imported {imported} out of {all}, skipped one duplicate" : "დაიმპორტდა {imported} სულ {all}-დან, გამოტოვებულ იქნა ერთი დუბლიკატი",
+    "Imported {imported} out of {all}, one failure" : "დაიმპორტდა {imported} სულ {all}-დან, ერთი წარუმატებლობა",
+    "Imported {imported} out of {all}, {errors} failures" : "დაიმპორტდა {imported} სულ {all}-დან, {errors} წარუმატებლობა",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "დაიმპორტდა {imported} სულ {all}-დან, გამოტოვებულ იქნა {duplicates} დუბლიკატი",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "დაიმპორტდა {imported} სულ {all}, {errors} წარუმატებლობა, გამოტოვებულ იქნა {duplicates} დუბლიკატი",
+    "Audio alarm {time} before the event starts" : "აუდიო განგაში მოვლენის დაწყებამდე {time}-ით ადრე",
+    "Pop-up {time} before the event starts" : "პოპ-აპ მოვლენის დაწყებამდე {time}-ით ადრე",
+    "Email {time} before the event starts" : "ელ-წერილი მოვლენის დაწყებამდე {time}-ით ადრე",
+    "None {time} before the event starts" : "არც ერთი მოვლენის დაწყებამდე {time}-ით ადრე",
     "{type} {time} before the event starts" : "{type} {time} სანამ მოვლენა დაიწყება",
+    "Audio alarm {time} before the event ends" : "აუდიო განგაში მოვლენის დასრულებამდე {time}-ით ადრე",
+    "Pop-up {time} before the event ends" : "პოპ-აპ მოვლენის დასრულებამდე {time}-ით ადრე",
+    "Email {time} before the event ends" : "ელ-წერილი მოვლენის დასრულებამდე {time}-ით ადრე",
+    "None {time} before the event ends" : "არც ერთი მოვლენის დასრულებამდე {time}-ით ადრე",
     "{type} {time} before the event ends" : "{type} {time} სანამ მოვლენა დასრულდება",
+    "Audio alarm {time} after the event starts" : "აუდიო განგაში მოვლენის დაწყების შემდეგ {time}-ით",
+    "Pop-up {time} after the event starts" : "პოპ-აპ მოვლენის დაწყების შემდეგ {time}-ით",
+    "Email {time} after the event starts" : "ელ-წერილი მოვლენის დაწყების შემდეგ {time}-ით",
+    "None {time} after the event starts" : "არც ერთი მოვლენის დაწყების შემდეგ {time}-ით",
     "{type} {time} after the event starts" : "{type} {time} რაც მოვლენა დაიწყება",
+    "Audio alarm {time} after the event ends" : "აუდიო განგაში მოვლენის დასრულების შემდეგ {time}-ით",
+    "Pop-up {time} after the event ends" : "პოპ-აპ მოვლენის დასრულების შემდეგ {time}-ით",
+    "Email {time} after the event ends" : "ელ-წერილი მოვლენის დასრულების შემდეგ {time}-ით",
+    "None {time} after the event ends" : "არც ერთი მოვლენის დასრულების შემდეგ {time}-ით",
     "{type} {time} after the event ends" : "{type} {time} რაც მოვლენა დასრულდება",
+    "Audio alarm at the event's start" : "მოვლენის დაწყებისას აუდიო განგაში",
+    "Pop-up at the event's start" : "პოპ-აპი მოვლენის დაწყებისას",
+    "Email at the event's start" : "ელ-წერილი მოვლენის დაწყებისას",
+    "None at the event's start" : "არც ერთი მოვლენის დაწყებისას",
     "{type} at the event's start" : "{type} მოვლენის დაწყებისას",
+    "Audio alarm at the event's end" : "აუდიო განგაში მოვლენის დასრულებისას",
+    "Pop-up at the event's end" : "პოპ-აპ მოვლენის დასრულებისას",
+    "Email at the event's end" : "ელ-წერილი მოვლენის დასრულებისას",
+    "None at the event's end" : "არც ერთი მოვლენის დასრულებისას",
     "{type} at the event's end" : "{type} მოვლენის დასრულებისას",
+    "Audio alarm at {time}" : "აუდიო განგაში დროზე {time}",
+    "Pop-up at {time}" : "პოპ-აპი დროზე {time}",
+    "Email at {time}" : "ელ-წერილი დროზე {time}",
+    "None at {time}" : "არაფერი დროზე {time}",
     "{type} at {time}" : "{type} at {time}",
     "{calendar} shared by {owner}" : "{calendar} გააზიარა მფლობელმა {owner}",
     "Please enter a valid WebCal-URL" : "გთხოვთ შეიყვანოთ მართებული WebCal მისამართი",
@@ -108,9 +145,6 @@ OC.L10N.register(
     "Week" : "კვირა",
     "Month" : "თვე",
     "Today" : "დღეს",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "გარკვეული მოვლენები კალენდარში გაფუჭებულია. დამატებითი ინფორმაციისთვის გთხოვთ იხილოთ JS კონსოლი.",
-    "Share Calendar" : "კალენდარის გაზიარება",
-    "Shared" : "გაზიარებული",
     "More" : "უფრო მეტი",
     "Edit" : "რედაქტირება",
     "Link" : "ბმული",
@@ -138,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "აბსოლუტური",
     "Repeat" : "გამეორება",
     "times every" : "დროს ყველა",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "ელ-ფოსტის შემახსენებლები ჯერ CalDAV სერვერზე არ შემოღებულა, ასე რომ არაფერი გაიგზავნება.",
     "Add" : "დამატება",
     "Email address of attendee" : "დამსწრების ელ-ფოსტის მისამართი",
     "Please add your email address in the personal settings in order to add attendees." : "დამსწრეების დასამატებლად გთხოვთ პირად პარამეტრებში დაამატოთ თქვენი ელ-ფოსტის მისამართი.",
