@@ -2,8 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "달력",
+    "%s has published the calendar »%s«" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
     "Hello," : "안녕하세요,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "%s 님이 달력 \"%s\"을(를) 공개했음을 알려 드립니다.",
+    "Open »%s«" : "%s 열기",
     "Cheers!" : "감사합니다!",
+    "Recipient" : "받는 사람",
     "Too many redirects. Aborting ..." : "너무 많은 넘겨주기, 중단합니다 ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "원격 서버에서 달력 접근을 허용하지 않음 (HTTP 오류 {%s})",
     "Error connecting to remote server" : "원격 서버 연결 오류",
@@ -22,8 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "달력을 먼저 생성하십시오.",
     "New event" : "새 일정",
     "CalDAV address for clients" : "클라이언트를 위한 CalDAV 주소",
-    "Error saving WebCal-calendar" : "WebCal 달력을 저장하는 중 오류 발생",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "이 달력의 일부 일정이 깨졌습니다. 더 많은 정보를 보려면 JS 콘솔을 참조하십시오.",
+    "Share Calendar" : "달력 공유",
+    "Shared" : "공유됨",
+    "Could not save WebCal-calendar" : "WebCal 달력을 저장할 수 없음",
     "WebDAV address for subscriptions" : "구독에 사용할 WebDAV 주소",
+    "Email sent." : "이메일을 보냈습니다.",
+    "Could not send your email." : "이메일을 보낼 수 없습니다.",
     "group" : "그룹",
     "Details" : "자세한 정보",
     "Attendees" : "참석자",
@@ -35,6 +44,9 @@ OC.L10N.register(
     "Confirmed" : "확인됨",
     "Tentative" : "예정됨",
     "Cancelled" : "취소됨",
+    "Please add a title." : "제목을 입력하십시오.",
+    "Please select a calendar." : "달력을 선택하십시오.",
+    "The event can not end before it starts." : "일정 시작 시간 이전에 종료할 수 없습니다.",
     "Global" : "전역",
     "None" : "없음",
     "Every day" : "매일",
@@ -53,6 +65,7 @@ OC.L10N.register(
     "2 hours before" : "2시간 전",
     "Custom" : "사용자 정의",
     "Audio" : "오디오",
+    "Email" : "이메일",
     "Pop-up" : "팝업",
     "sec" : "초",
     "min" : "분",
@@ -64,12 +77,46 @@ OC.L10N.register(
     "end" : "끝",
     "Editing reminders of unknown type not supported." : "알 수 없는 형식의 미리 알림을 편집할 수 없습니다.",
     "Week {number} of {year}" : "{year}년 제 {number}주",
+    "Successfully imported {imported} objects" : "객체 {imported}개 가져옴",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{all}개 중 {imported}개 가져옴, 중복된 항목 1개 제외함",
+    "Imported {imported} out of {all}, one failure" : "{all}개 중 {imported}개 가져옴, 실패한 항목 1개 제외함",
+    "Imported {imported} out of {all}, {errors} failures" : "{all}개 중 {imported}개 가져옴, 실패한 항목 {errors}개 제외함",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{all}개 중 {imported}개 가져옴, 중복된 항목 {duplicates}개 제외함",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{all}개 중 {imported}개 가져옴, 실패한 항목 {errors}개 및 중복된 항목 {duplicates}개 제외함",
+    "Audio alarm {time} before the event starts" : "일정 시작 {time} 전에 알람음 재생",
+    "Pop-up {time} before the event starts" : "일정 시작 {time} 전에 팝업 메시지 표시",
+    "Email {time} before the event starts" : "일정 시작 {time} 전에 이메일 보내기",
+    "None {time} before the event starts" : "일정 시작 {time} 전에 아무것도 하지 않음",
     "{type} {time} before the event starts" : "일정 시작 {time} 전 {type}",
+    "Audio alarm {time} before the event ends" : "일정 종료 {time} 전에 알람음 재생",
+    "Pop-up {time} before the event ends" : "일정 종료 {time} 전에 팝업 메시지 표시",
+    "Email {time} before the event ends" : "일정 종료 {time} 전에 이메일 보내기",
+    "None {time} before the event ends" : "일정 종료 {time} 전에 아무것도 하지 않음",
     "{type} {time} before the event ends" : "일정 종료 {time} 전 {type}",
+    "Audio alarm {time} after the event starts" : "일정 시작 {time} 후에 알람음 재생",
+    "Pop-up {time} after the event starts" : "일정 시작 {time} 후에 팝업 메시지 표시",
+    "Email {time} after the event starts" : "일정 시작 {time} 후에 이메일 보내기",
+    "None {time} after the event starts" : "일정 시작 {time} 후에 아무것도 하지 않음",
     "{type} {time} after the event starts" : "일정 시작 {time} 후 {type}",
+    "Audio alarm {time} after the event ends" : "일정 종료 {time} 후에 알람음 재생",
+    "Pop-up {time} after the event ends" : "일정 종료 {time} 후에 팝업 메시지 표시",
+    "Email {time} after the event ends" : "일정 종료 {time} 후에 이메일 보내기",
+    "None {time} after the event ends" : "일정 종료 {time} 후에 아무것도 하지 않음",
     "{type} {time} after the event ends" : "일정 종료 {time} 후 {type}",
+    "Audio alarm at the event's start" : "일정 시작 시 알람음 재생",
+    "Pop-up at the event's start" : "일정 시작 시 팝업 메시지 표시",
+    "Email at the event's start" : "일정 시작 시 이메일 보내기",
+    "None at the event's start" : "일정 시작 시 아무것도 하지 않음",
     "{type} at the event's start" : "일정 시작 시 {type}",
+    "Audio alarm at the event's end" : "일정 종료 시 알람음 재생",
+    "Pop-up at the event's end" : "일정 종료 시 팝업 메시지 표시",
+    "Email at the event's end" : "일정 종료 시 이메일 보내기",
+    "None at the event's end" : "일정 종료 시 아무것도 하지 않음",
     "{type} at the event's end" : "일정 종료 시 {type}",
+    "Audio alarm at {time}" : "{time}에 알람음 재생",
+    "Pop-up at {time}" : "{time}에 팝업 메시지 표시",
+    "Email at {time}" : "{time}에 이메일 보내기",
+    "None at {time}" : "{time}에 아무것도 하지 않음",
     "{type} at {time}" : "{time}에 {type}",
     "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
     "Please enter a valid WebCal-URL" : "올바른 WebCal URL을 입력하십시오",
@@ -98,9 +145,6 @@ OC.L10N.register(
     "Week" : "주",
     "Month" : "달",
     "Today" : "오늘",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "이 달력의 일부 일정이 깨졌습니다. 더 많은 정보를 보려면 JS 콘솔을 참조하십시오.",
-    "Share Calendar" : "달력 공유",
-    "Shared" : "공유됨",
     "More" : "더 보기",
     "Edit" : "편집",
     "Link" : "링크",
@@ -117,6 +161,8 @@ OC.L10N.register(
     "New Subscription" : "새 구독",
     "Go back" : "뒤로 가기",
     "Go forward" : "앞으로 가기",
+    "Calendar does not exist" : "달력이 존재하지 않음",
+    "Maybe you got a wrong link or the calendar was unshared?" : "잘못된 링크를 받았거나 달력의 공유가 해제되었을 수도 있습니다.",
     "Edit event" : "일정 편집",
     "Delete Event" : "일정 삭제",
     "Save Event" : "일정 저장",
@@ -125,7 +171,10 @@ OC.L10N.register(
     "Relative" : "상대적",
     "Absolute" : "절대적",
     "Repeat" : "반복",
+    "times every" : "회/주기",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "CalDAV 서버에 이메일 알림이 구현되지 않았기 때문에 메시지가 전송되지 않을 것입니다.",
     "Add" : "추가",
+    "Email address of attendee" : "참석자의 이메일 주소",
     "Please add your email address in the personal settings in order to add attendees." : "참석자 목록을 편집하려면 개인 설정에서 이메일 주소를 추가하십시오.",
     "from" : "시작",
     "to" : "끝",
@@ -142,6 +191,9 @@ OC.L10N.register(
     "New calendar" : "새 달력",
     "File is empty" : "파일이 비어 있음",
     "Import scheduled" : "가져오기 예약됨",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s 님이 내게 달력 <strong>%s</strong>을(를) 공유함",
+    "Embed" : "임베드",
+    "Iframe to integrate" : "통합할 IFrame",
     "Publish URL" : "URL 공개",
     "Settings & import" : "설정 및 가져오기",
     "Skip simple event editor" : "간단한 이벤트 편집기 건너뛰기",
@@ -149,6 +201,7 @@ OC.L10N.register(
     "Import calendar" : "달력 가져오기",
     "No Calendars selected for import" : "가져올 달력을 선택하지 않았음",
     "Primary CalDAV address" : "주 CalDAV 주소",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 주소"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 주소",
+    "Subscribe" : "구독"
 },
 "nplurals=1; plural=0;");
