@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Prašome sukurti kalendorių.",
     "New event" : "Naujas įvykis",
     "CalDAV address for clients" : "CalDAV adresas",
-    "Error saving WebCal-calendar" : "Klaida, įrašant WebCal kalendorių",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie šio kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS pultą.",
+    "Share Calendar" : "Dalintis kalendoriumi",
+    "Shared" : "Dalinamasi",
     "WebDAV address for subscriptions" : "WebDAV adresas prenumeratoms",
-    "Email has been sent." : "El. laiškas išsiųstas.",
-    "There was an issue while sending your email." : "Siunčiant jūsų laišką įvyko klaida.",
     "group" : "grupė",
     "Details" : "Išsamiau",
     "Attendees" : "Dalyviai",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Savaitė",
     "Month" : "Mėnuo",
     "Today" : "Šiandien",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie šio kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS pultą.",
-    "Share Calendar" : "Dalintis kalendoriumi",
-    "Shared" : "Dalinamasi",
     "More" : "Daugiau",
     "Edit" : "Redaguoti",
     "Link" : "Nuoroda",
