@@ -22,10 +22,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Lūdzu vispirms izveido kalendāru.",
     "New event" : "Jauns notikums",
     "CalDAV address for clients" : "CalDAV adrese klientiem",
-    "Error saving WebCal-calendar" : "Kļūda saglabājot WebCal-calendar",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Daži notikumi kalendārā ir bojāti. Papildus informācijai pārbadiet JS konsoli.",
+    "Share Calendar" : "Koplietot kalendāru",
+    "Shared" : "Koplietots",
     "WebDAV address for subscriptions" : "WebDAV adrese abonementiem",
-    "Email has been sent." : "E-pasts nosūtīts.",
-    "There was an issue while sending your email." : "Notikusi kļūda sūtot e-pastu.",
     "group" : "grupa",
     "Details" : "Detaļas",
     "Attendees" : "Apmeklētāji",
@@ -101,9 +101,6 @@ OC.L10N.register(
     "Week" : "Nedēļa",
     "Month" : "Mēnesis",
     "Today" : "Šodien",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Daži notikumi kalendārā ir bojāti. Papildus informācijai pārbadiet JS konsoli.",
-    "Share Calendar" : "Koplietot kalendāru",
-    "Shared" : "Koplietots",
     "More" : "Vairāk",
     "Edit" : "Rediģēt",
     "Link" : "Saite",
