@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Та эхлээд цагийн хуваариа үүсгэнэ үү.",
     "New event" : "Шинэ үйл явдал",
     "CalDAV address for clients" : "CalDAV хаяг",
-    "Error saving WebCal-calendar" : "WebCal цагийн хуваарь хадгалахад алдаа гарлаа",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Энэ цагийн хуваарь дахь зарим үйл явдал эвдэрсэн байна. JS console ашиглан дэлгэрэнгүй мэдээлэл авна уу.",
+    "Share Calendar" : "Календарь түгээх",
+    "Shared" : "Түгээсэн",
     "WebDAV address for subscriptions" : "WebDAV хаяг",
-    "Email has been sent." : "Цахим шууданг илгээв.",
-    "There was an issue while sending your email." : "Таны цахим шууданг илгээхэд алдаа гарлаа.",
     "group" : "бүлэг",
     "Details" : "Дэлгэрэнгүй",
     "Attendees" : "Оролцогчид",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Долоо хоног",
     "Month" : "Сар",
     "Today" : "Өнөөдөр",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Энэ цагийн хуваарь дахь зарим үйл явдал эвдэрсэн байна. JS console ашиглан дэлгэрэнгүй мэдээлэл авна уу.",
-    "Share Calendar" : "Календарь түгээх",
-    "Shared" : "Түгээсэн",
     "More" : "Дэлгэрэнгүй",
     "Edit" : "Засах",
     "Link" : "Холбоос",
