@@ -26,10 +26,11 @@ OC.L10N.register(
     "Please create a calendar first." : "Opprett en kalender først",
     "New event" : "Ny hendelse",
     "CalDAV address for clients" : "CalDAV adresse for klienter",
-    "Error saving WebCal-calendar" : "Feil under lagring av WebCal-kalender",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Sjekk JS-konsollen for mer info.",
+    "Share Calendar" : "Del kalender",
+    "Shared" : "Delt",
     "WebDAV address for subscriptions" : "WebDAV-adresse for abonnementer",
-    "Email has been sent." : "E-post er sendt.",
-    "There was an issue while sending your email." : "Problem ved forsendelse av din e-post.",
+    "Email sent." : "E-post sendt.",
     "group" : "gruppe",
     "Details" : "Detaljer",
     "Attendees" : "Deltakere",
@@ -74,12 +75,24 @@ OC.L10N.register(
     "end" : "slutt",
     "Editing reminders of unknown type not supported." : "Redigering av varsler av ukjent type støttes ikke.",
     "Week {number} of {year}" : "Uke {number} {year}",
+    "Successfully imported {imported} objects" : "Importerte {imported} objekter",
+    "Imported {imported} out of {all}, one failure" : "Importerte {imported} av {all}, én feil",
     "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
     "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
     "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
     "{type} {time} after the event ends" : "{type} {time} etter hendelsen slutter",
+    "Pop-up at the event's start" : "Oppsprett ved hendelsens start",
+    "Email at the event's start" : "E-post ved hendelsens start",
+    "None at the event's start" : "Ingen ved hendelsens start",
     "{type} at the event's start" : "{type} ved hendelsens start",
+    "Audio alarm at the event's end" : "Lydalarm ved hendelsens slutt",
+    "Pop-up at the event's end" : "Oppsprett ved hendelsens slutt",
+    "Email at the event's end" : "E-post ved hendelsens slutt",
+    "None at the event's end" : "Ingen ved hendelsens slutt",
     "{type} at the event's end" : "{type} ved hendelsens slutt",
+    "Pop-up at {time}" : "Oppsprett klokka {time}",
+    "Email at {time}" : "E-post klokka {time}",
+    "None at {time}" : "Ingenting klokka {time}",
     "{type} at {time}" : "{type} {time}",
     "{calendar} shared by {owner}" : "{calendar} delt av {owner}",
     "Please enter a valid WebCal-URL" : "Oppgi en WebCal-URL",
@@ -108,9 +121,6 @@ OC.L10N.register(
     "Week" : "Uke",
     "Month" : "Måned",
     "Today" : "I dag",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Sjekk JS-konsollen for mer info.",
-    "Share Calendar" : "Del kalender",
-    "Shared" : "Delt",
     "More" : "Mer",
     "Edit" : "Rediger",
     "Link" : "Lenke",
@@ -138,6 +148,7 @@ OC.L10N.register(
     "Absolute" : "Absolutt",
     "Repeat" : "Gjenta",
     "times every" : "ganger hver",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-postpåminnelser har ikke blitt implementert i CalDAV-tjeneren enda, så ingen vil bli sendt.",
     "Add" : "Legg til",
     "Email address of attendee" : "E-postadresse for deltaker",
     "Please add your email address in the personal settings in order to add attendees." : "Legg inn e-postadressen din i personlige innstillinger for å kunne legge til deltakere.",
