@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Creează un calendar mai întâi.",
     "New event" : "Eveniment nou",
     "CalDAV address for clients" : "CalDAV adresa pentru clienți",
-    "Error saving WebCal-calendar" : "Eroare la salvarea calendarului WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Anumite evenimente din acest calendar sunt invalide. Vă rugăm să verificați consola JS pentru mai multe informatii.",
+    "Share Calendar" : "Partajează calendarul",
+    "Shared" : "Partajat",
     "WebDAV address for subscriptions" : "WebDAV adresa pentru abonamente",
-    "Email has been sent." : "Email-ul a fost trimis",
-    "There was an issue while sending your email." : "A aparut o eroare la transmiterea email-ului.",
     "group" : "grup",
     "Details" : "Detalii",
     "Attendees" : "Participanți",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Săptămâna",
     "Month" : "Luna",
     "Today" : "Astăzi",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Anumite evenimente din acest calendar sunt invalide. Vă rugăm să verificați consola JS pentru mai multe informatii.",
-    "Share Calendar" : "Partajează calendarul",
-    "Shared" : "Partajat",
     "More" : "Mai mult",
     "Edit" : "Editează",
     "Link" : "Legătură",
