@@ -26,10 +26,11 @@ OC.L10N.register(
     "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
     "New event" : "Nová udalosť",
     "CalDAV address for clients" : "CalDAV adresa pre klientov",
-    "Error saving WebCal-calendar" : "Chyba pri ukladaní WebCal-kalendára",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
+    "Share Calendar" : "Sprístupniť kalendár",
+    "Shared" : "Sprístupnené",
     "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
-    "Email has been sent." : "E-mail bol odoslaný.",
-    "There was an issue while sending your email." : "Vyskytol sa problém pri odosielaní e-mailu.",
+    "Email sent." : "Email odoslaný.",
     "group" : "skupina",
     "Details" : "Podrobnosti",
     "Attendees" : "Účastníci",
@@ -76,12 +77,33 @@ OC.L10N.register(
     "Week {number} of {year}" : "Týždeň {number} roku {year}",
     "Successfully imported {imported} objects" : "Úspešne importované {imported} objekty",
     "Imported {imported} out of {all}, skipped one duplicate" : "Importované {imported} z {all}, preskočený jeden duplikát",
+    "Audio alarm {time} before the event starts" : "Zvukový alarm {time} pred začiatkom udalosti",
+    "Pop-up {time} before the event starts" : "Vyskakovacie okno {time} pred začiatkom udalosti",
+    "Email {time} before the event starts" : "Email {time} pred začiatkom udalosti",
     "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
+    "Audio alarm {time} before the event ends" : "Zvukový alarm {time} pred koncom udalosti",
+    "Pop-up {time} before the event ends" : "Vyskakovacie okno {time} pred koncom udalosti",
+    "Email {time} before the event ends" : "Email {time} pred koncom udalosti",
     "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
+    "Audio alarm {time} after the event starts" : "Zvukový alarm {time} po začiatku udalosti",
+    "Pop-up {time} after the event starts" : "Vyskakovacie okno {time} po začiatku udalosti",
+    "Email {time} after the event starts" : "Email {time} po začiatku udalosti",
     "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
+    "Audio alarm {time} after the event ends" : "Zvukový alarm {time} po konci udalosti",
+    "Pop-up {time} after the event ends" : "Vyskakovacie okno {time} po konci udalosti",
+    "Email {time} after the event ends" : "Email {time} po konci udalosti",
     "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
+    "Audio alarm at the event's start" : "Zvukový alarm pri začiatku udalosti",
+    "Pop-up at the event's start" : "Vyskakovacie okno pri začiatku udalosti",
+    "Email at the event's start" : "Email pri začiatku udalosti",
     "{type} at the event's start" : "{type} pri začiatku udalosti",
+    "Audio alarm at the event's end" : "Zvukový alarm pri konci udalosti",
+    "Pop-up at the event's end" : "Vyskakovacie okno pri konci udalosti",
+    "Email at the event's end" : "Email pri konci udalosti",
     "{type} at the event's end" : "{type} pri skončení udalosti",
+    "Audio alarm at {time}" : "Zvukový alarm o {time}",
+    "Pop-up at {time}" : "Vyskakovacie okno o {time}",
+    "Email at {time}" : "Email o {time}",
     "{type} at {time}" : "{type} o {time}",
     "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
     "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
@@ -110,9 +132,6 @@ OC.L10N.register(
     "Week" : "Týždeň",
     "Month" : "Mesiac",
     "Today" : "Dnes",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
-    "Share Calendar" : "Sprístupniť kalendár",
-    "Shared" : "Sprístupnené",
     "More" : "Viac",
     "Edit" : "Upraviť",
     "Link" : "Odkaz",
