@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Calendar" : "Koledar",
     "%s has published the calendar »%s«" : "%s je objavil koledar \"%s\"",
-    "Hello," : "Živjo,",
+    "Hello," : "Živijo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Želimo te obvestiti, da je %s objavil(a) koledar %s.",
     "Open »%s«" : "Odpri »%s«",
     "Cheers!" : "Lep pozdrav!",
@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
     "New event" : "Nov dogodek",
     "CalDAV address for clients" : "CalDAV naslov za odjemalce",
-    "Error saving WebCal-calendar" : "Napaka shranjevanja koledarja WebCal",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
+    "Share Calendar" : "Omogoči souporabo koledarja",
+    "Shared" : "V souporabi",
     "WebDAV address for subscriptions" : "WebDAV naslov za naročnike",
-    "Email has been sent." : "E-pošta je bila poslana.",
-    "There was an issue while sending your email." : "Prišlo je do napake pri pošiljanju e-pošte.",
     "group" : "skupina",
     "Details" : "Podrobnosti",
     "Attendees" : "Udeleženci",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Teden",
     "Month" : "Mesec",
     "Today" : "Danes",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
-    "Share Calendar" : "Omogoči souporabo koledarja",
-    "Shared" : "V souporabi",
     "More" : "Več",
     "Edit" : "Uredi",
     "Link" : "Povezava",
