@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
     "New event" : "Veprimtari e re",
     "CalDAV address for clients" : "Adresa CalDAV për klientët",
-    "Error saving WebCal-calendar" : "Gabim në ruajtje kalendari WebCal-calendar",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
+    "Share Calendar" : "Ndani Kalendarin",
+    "Shared" : "E ndarë",
     "WebDAV address for subscriptions" : "Adresa WebDAV për abonimet",
-    "Email has been sent." : "Emaili u dërgua",
-    "There was an issue while sending your email." : "Pati një problem me dërgimin e emailit tuaj.",
     "group" : "grup",
     "Details" : "Detajet",
     "Attendees" : "Pjesëmarrës",
@@ -108,9 +108,6 @@ OC.L10N.register(
     "Week" : "Javë",
     "Month" : "Muaj",
     "Today" : "Sot",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
-    "Share Calendar" : "Ndani Kalendarin",
-    "Shared" : "E ndarë",
     "More" : "Më tepër",
     "Edit" : "Përpunoni",
     "Link" : "Lidhje",
