@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "Молимо прво направите календар.",
     "New event" : "Нови догађај",
     "CalDAV address for clients" : "CalDAV адреса за клијенте",
-    "Error saving WebCal-calendar" : "Грешка при чувању WebCal календара",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Неки догађаји у календару су оштећени. За више информација, проверите JS конзолу",
+    "Share Calendar" : "Подели календар",
+    "Shared" : "Дељено",
+    "Could not save WebCal-calendar" : "Не могу да сачувам WebCal календар",
     "WebDAV address for subscriptions" : "WebDAV адреса за претплату",
-    "Email has been sent." : "Е-пошта је послата.",
-    "There was an issue while sending your email." : "Догодила се грешка приликом слања е-поште.",
+    "Email sent." : "Е-пошта послата.",
+    "Could not send your email." : "Не могу да пошаљем е-пошту.",
     "group" : "група",
     "Details" : "Детаљи",
     "Attendees" : "Присутни",
@@ -74,12 +77,46 @@ OC.L10N.register(
     "end" : "завршетак",
     "Editing reminders of unknown type not supported." : "Измена подсетника непознатог типа није подржана.",
     "Week {number} of {year}" : "Недеља {number} у {year}",
-    "{type} {time} before the event starts" : "{type} {time} пре него догађај почне",
-    "{type} {time} before the event ends" : "{type} {time} пре него се догађај заврши",
-    "{type} {time} after the event starts" : "{type} {time} пошто догађај почне",
+    "Successfully imported {imported} objects" : "Успешно увезено {imported} објеката",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Увезено {imported} од {all}, прескочен један дупликат",
+    "Imported {imported} out of {all}, one failure" : "Увезено {imported} од {all}, једна грешка",
+    "Imported {imported} out of {all}, {errors} failures" : "Увезено {imported} од {all}, {errors} грешака",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Увезено {imported} од {all}, прескочено {duplicates} дупликата",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Увезено {imported} од {all},  {errors} грешака, прескочено {duplicates} дупликата",
+    "Audio alarm {time} before the event starts" : "Звучни аларм {time} пре почетка догађаја",
+    "Pop-up {time} before the event starts" : "Искочи {time} пре почетка догађаја",
+    "Email {time} before the event starts" : "Пошаљи е-пошту {time} пре почетка догађаја",
+    "None {time} before the event starts" : "Ништа {time} пре почетка догађаја",
+    "{type} {time} before the event starts" : "{type} {time} пре почетка догађаја",
+    "Audio alarm {time} before the event ends" : "Звучни аларм {time} пре краја догађаја",
+    "Pop-up {time} before the event ends" : "Искочи {time} пре краја догађаја",
+    "Email {time} before the event ends" : "Пошаљи е-пошту {time} пре краја догађаја",
+    "None {time} before the event ends" : "Ништа {time} пре краја догађаја",
+    "{type} {time} before the event ends" : "{type} {time} пре краја догађаја",
+    "Audio alarm {time} after the event starts" : "Звучни аларм {time} након што догађај почне",
+    "Pop-up {time} after the event starts" : "Искочи {time} након што догађај почне",
+    "Email {time} after the event starts" : "Пошаљи е-пошту {time} након што догађај почне",
+    "None {time} after the event starts" : "Ништа {time} након што догађај почне",
+    "{type} {time} after the event starts" : "{type} {time} након што догађај почне",
+    "Audio alarm {time} after the event ends" : "Звучни аларм {time} пошто се догађај заврши",
+    "Pop-up {time} after the event ends" : "Искочи {time} пошто се догађај заврши",
+    "Email {time} after the event ends" : "Пошаљи е-пошту {time} пошто се догађај заврши",
+    "None {time} after the event ends" : "Ништа {time} пошто се догађај заврши",
     "{type} {time} after the event ends" : "{type} {time} пошто се догађај заврши",
+    "Audio alarm at the event's start" : "Звучни аларм када догађај почне",
+    "Pop-up at the event's start" : "Искочи када догађај почне",
+    "Email at the event's start" : "Пошаљи е-пошту када догађај почне",
+    "None at the event's start" : "Ништа када догађај почне",
     "{type} at the event's start" : "{type} када догађај почне",
+    "Audio alarm at the event's end" : "Звучни аларм када се догађај заврши",
+    "Pop-up at the event's end" : "Искочи када се догађај заврши",
+    "Email at the event's end" : "Пошаљи е-пошту када се догађај заврши",
+    "None at the event's end" : "Ништа када се догађај заврши",
     "{type} at the event's end" : "{type} када се догађај заврши",
+    "Audio alarm at {time}" : "Звучни аларм у {time}",
+    "Pop-up at {time}" : "Искочи у {time}",
+    "Email at {time}" : "Пошаљи е-пошту у {time}",
+    "None at {time}" : "Ништа у {time}",
     "{type} at {time}" : "{type} у {time}",
     "{calendar} shared by {owner}" : "{calendar} је подељен од стране {owner}",
     "Please enter a valid WebCal-URL" : "Унесите исправну WebCal адресу",
@@ -108,9 +145,6 @@ OC.L10N.register(
     "Week" : "Недеља",
     "Month" : "Месец",
     "Today" : "Данас",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Неки догађаји у календару су оштећени. За више информација, проверите JS конзолу",
-    "Share Calendar" : "Подели календар",
-    "Shared" : "Дељено",
     "More" : "Остало",
     "Edit" : "Измени",
     "Link" : "Веза",
@@ -138,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Апсолутно",
     "Repeat" : "Понављај",
     "times every" : "пута сваких",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Подсетници преко е-поште још нису имплементирани у CalDAV серверу, и зато ништа неће бити послато.",
     "Add" : "Додај",
     "Email address of attendee" : "Адреса е-поште учесника",
     "Please add your email address in the personal settings in order to add attendees." : "Додајте адресу Ваше е-поште у личним подешавањима да бисте додали учеснике",
