@@ -26,10 +26,10 @@ OC.L10N.register(
     "Please create a calendar first." : "Vänligen skapa en kalender först.",
     "New event" : "Ny händelse",
     "CalDAV address for clients" : "CalDAV adress för klienter",
-    "Error saving WebCal-calendar" : "Ett fel uppstod när WebCal-kalendern sparades",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Några händelser i kalendern är felaktiga. Vänligen kolla JS-konsolen för mer information.",
+    "Share Calendar" : "Dela kalender",
+    "Shared" : "Delat",
     "WebDAV address for subscriptions" : "WebDAV-adress för prenumerationer",
-    "Email has been sent." : "E-post har skickats.",
-    "There was an issue while sending your email." : "Det uppstod problem när e-post skickades till dig.",
     "group" : "Grupp",
     "Details" : "Detaljer",
     "Attendees" : "Deltagare",
@@ -74,12 +74,32 @@ OC.L10N.register(
     "end" : "slut",
     "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
     "Week {number} of {year}" : "Vecka {number} år {year}",
+    "Audio alarm {time} before the event starts" : "Ljudalarm {time} före händelsen startar",
+    "Email {time} before the event starts" : "Epost {time} före händelsen startar",
     "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
     "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
+    "Email {time} after the event starts" : "E-posta {time} efter händelsen startar",
+    "None {time} after the event starts" : "Gör inget {time} efter händelsen startas",
     "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
+    "Audio alarm {time} after the event ends" : "Ljudalarm {time} efter händelsen slutar",
+    "Pop-up {time} after the event ends" : "Pop-up {time} efter händelsen slutar",
+    "Email {time} after the event ends" : "E-posta {time} efter händelsen slutar",
+    "None {time} after the event ends" : "Gör inget {time} efter händelsen slutar",
     "{type} {time} after the event ends" : "{type} {time} efter händelsen slutar",
+    "Audio alarm at the event's start" : "Ljudalarm vid händelsens början",
+    "Pop-up at the event's start" : "Pop-up vid händelsens start",
+    "Email at the event's start" : "E-posta vid händelsens början",
+    "None at the event's start" : "Inget vid händelsens början",
     "{type} at the event's start" : "{type} vid händelsens början",
+    "Audio alarm at the event's end" : "Ljudalarm vid händelsens slut",
+    "Pop-up at the event's end" : "Pop-up vid händelsens slut",
+    "Email at the event's end" : "E-posta vid händelsens slut",
+    "None at the event's end" : "Inget vid händelsens slut",
     "{type} at the event's end" : "{type} vid händelsens slut",
+    "Audio alarm at {time}" : "Ljudalarm vid {time}",
+    "Pop-up at {time}" : "Pop-up vid {time}",
+    "Email at {time}" : "E-post vid {time}",
+    "None at {time}" : "Inget vid {time}",
     "{type} at {time}" : "{type} vid {time}",
     "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
     "Please enter a valid WebCal-URL" : "Vänligen ange en giltig WebCal-URL",
@@ -108,9 +128,6 @@ OC.L10N.register(
     "Week" : "Vecka",
     "Month" : "Månad",
     "Today" : "Idag",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Några händelser i kalendern är felaktiga. Vänligen kolla JS-konsolen för mer information.",
-    "Share Calendar" : "Dela kalender",
-    "Shared" : "Delat",
     "More" : "Mer",
     "Edit" : "Ändra",
     "Link" : "Länk",
