@@ -26,10 +26,13 @@ OC.L10N.register(
     "Please create a calendar first." : "Lütfen önce bir takvim oluşturun.",
     "New event" : "Yeni etkinlik",
     "CalDAV address for clients" : "İstemciler için CalDAV adresi",
-    "Error saving WebCal-calendar" : "WebCal takvimi kaydedilirken sorun çıktı",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Bu takvimdeki bazı etkinliklerde sorun var. Ayrıntılı bilgi almak için JS konsoluna bakın.",
+    "Share Calendar" : "Takvimi Paylaş",
+    "Shared" : "Paylaşıldı",
+    "Could not save WebCal-calendar" : "WebCal takvimi kaydedilemedi",
     "WebDAV address for subscriptions" : "Abonelikler için WebDAV adresi",
-    "Email has been sent." : "E-posta gönderildi.",
-    "There was an issue while sending your email." : "E-posta gönderilirken bir sorun çıktı.",
+    "Email sent." : "E-posta gönderildi.",
+    "Could not send your email." : "E-posta gönderilemedi.",
     "group" : "grup",
     "Details" : "Ayrıntılar",
     "Attendees" : "Katılanlar",
@@ -142,9 +145,6 @@ OC.L10N.register(
     "Week" : "Hafta",
     "Month" : "Ay",
     "Today" : "Bugün",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Bu takvimdeki bazı etkinliklerde sorun var. Ayrıntılı bilgi almak için JS konsoluna bakın.",
-    "Share Calendar" : "Takvimi Paylaş",
-    "Shared" : "Paylaşıldı",
     "More" : "Diğer",
     "Edit" : "Düzenle",
     "Link" : "Bağlantı",
@@ -172,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Mutlak",
     "Repeat" : "Yineleme",
     "times every" : "kez, her",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-posta anımsatıcı özelliği henüz CalDAV sunucusuna eklenmediğinden herhangi bir e-posta gönderilmeyecek.",
     "Add" : "Ekle",
     "Email address of attendee" : "Katılımcının e-posta adresi",
     "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
